@@ -7,7 +7,7 @@ from .h5_dataset import H5Dataset
 
 class Kather96x96(H5Dataset):
     """
-    Kather dataset, more information can be found at TODO
+    Kather dataset, more information can be found at https://zenodo.org/record/1214456
     """
 
     def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
@@ -23,12 +23,12 @@ class Kather96x96(H5Dataset):
 
     @classmethod
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
-        return cls('/data/ldap/histopathologic/processed_read_only/Kather_96', sub_set, transform,transform_target)
+        return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res96', sub_set, transform,transform_target)
 
 
 class Kather224x224(H5Dataset):
     """
-    Kather dataset, more information can be found at TODO
+    Kather dataset, more information can be found at https://zenodo.org/record/1214456
     """
 
     def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
@@ -44,4 +44,4 @@ class Kather224x224(H5Dataset):
 
     @classmethod
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
-        return cls('/data/ldap/histopathologic/processed_read_only/Kather_224', sub_set, transform, transform_target)
\ No newline at end of file
+        return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res224', sub_set, transform, transform_target)
\ No newline at end of file
